@@ -74,7 +74,10 @@ def update_schemes_tried_bytes(kdamond_idxs):
 def update_schemes_tried_regions(kdamond_idxs):
     err = __write_state_file(kdamond_idxs, 'update_schemes_tried_regions')
     if err != None:
-        err = '%s (maybe schemes_tried_regions not supported?)' % err
+        if not feature_supported('schemes_tried_regions'):
+            err = '%s (DAMON feature \'schemes_tried_regions\' is not supported on the current kernel. It is available on kernel version 6.2 and later)' % err
+        else:
+            err = '%s (concurrent threads doing writes)' % err
     return err
 
 'Return error'
